/* OS specific routines for AMIGA platform.
 *
 * John Bush    <JBush@landfill.east.sun.com>  BIX: jbush
 * Paul Kienitz <Paul.Kienitz@f28.n125.z1.fidonet.org>
 *
 * History:
 *
 * Date     DoBee    Comments
 * -------  -------- -----------------------------------------------
 * 21Jan93  JBush    Original coding.
 *                   Incorporated filedate.c (existing routine).
 *
 * 31Jan93  JBush    Made filedate.c include unconditional.
 *
 * 18Jul93  PaulK    Moved Aztec _abort() here from stat.c because we
 *                   can't share the same one between Zip and UnZip.
 *                   Added close_leftover_open_dirs() call to it.
 *
 * 17Apr95  PaulK    Added Amiga internal version string so that
 *                   installer programs can compare the version being
 *                   installed to see if the copy the user already has
 *                   is older or newer.  Added Prestart_Hook to support
 *                   debug tracing in deflate.a.
 *
 *  6May95  PaulK    Added GetComment() for filenote support.
 */

#include "ziperr.h"
void ziperr(int c, char *h);

/* ============================================================ */
/* filedate.c is an external file, since it's shared with UnZip */

#include "amiga/filedate.c"

#ifdef AZTEC_C
#  include <fcntl.h>
#  ifdef DEBUG
#    define PRESTART_HOOK
#  endif

/* ============================================================ */
/* the same applies to stat.c, but only for Aztec               */

#  include "amiga/stat.c"

/* the following handles cleanup when a ^C interrupt happens: */

void set_con(void);

void _abort(void)               /* called when ^C is pressed */
{
    close_leftover_open_dirs();
#ifdef CRYPT
    echon();   /* this is what echon() is defined as in non-dummy crypt.h */
#endif
    ziperr(ZE_ABORT, "^C");
}

#endif /* AZTEC_C */

/* Make sure the version number here matches the mumber in revision.h */
/* as closely as possible in strict decimal "#.#" form:               */
static char version_id[] = "\0$VER: Zip 2.1 ("
#  include "env:VersionDate"
")\r\n";

/* call this with an arg of NULL to free storage: */

char *GetComment(char *filename)
{
    BPTR lk;
    static struct FileInfoBlock *fib = NULL;

    if (!filename) {
        if (fib) FreeMem(fib, sizeof(*fib));
        fib = NULL;
        return NULL;
    }
    if (!fib) {
        if (!(fib = AllocMem(sizeof(*fib), MEMF_PUBLIC)))
            ziperr(ZE_MEM, "was checking filenotes");
    }
    if (!(lk = Lock(filename, ACCESS_READ)))
        return NULL;
    if (!Examine(lk, fib))
        fib->fib_Comment[0] = '\0';
    UnLock(lk);
    return fib->fib_Comment[0] ? &fib->fib_Comment[0] : NULL;
}
